% Function computes a control vector for the model's actuators
%
% Input:
%   osimModel: org.opensim.Modeling.Model object
%   osimState: org.opensim.Modeling.State object
%
% Output:
%   outVector: org.opensim.Modeling.Vector of control values
%
function modelControls = opensim_actControl(osimModel, osimState)
% Load Library
import org.opensim.modeling.*;

if(osimModel.getNumControls() < 1)
    error('opensim_actControl:InvalidControls', 'This model has no controls.');
end

% Get a reference to current model controls
modelControls = osimModel.updControls(osimState) ;

% Initialize a vector for the actuator controls
actControls = Vector(1, 0.0) ;

% Calculate the controls based on any property of the model or state
Coord = osimModel.getCoordinateSet().get('ankle_rz').getValue(osimState) ;
timeT = osimState.getTime() ;

% Control Function
val = 6.8470e+06*timeT^6 - 5.4524e+06*timeT^5 + 1.7157e+06*timeT^4 - 2.7095e+05*timeT^3 + 2.4187e+04*timeT^2 - 1.3762e+03*timeT - 47.6360 ;

global valSave v
valSave(v, 1) = timeT  ; valSave(v, 2) = Coord  ; valSave(v, 3) = val  ;
v = v + 1 ;

% Set Actuator Controls
actControls.set(0, val) ;
    
% Update model Controls with the new values
osimModel.updActuators().get('ankleActuator').addInControls(actControls, modelControls) ;

end